<?php
/**
 * Google Tag Manager
 *
 * NOTICE OF LICENSE
 *
 * @author    David Escudero
 * @copyright DavidEscudero
 * @license   Usalo cuando quieras y como quieras
 * @version 1.0.0
 *
 * **************************************************
 * *                Google Tag Manager              *
 * *          https://davidescudero.com             *
 * *                     V 1.0.0                    *
 * **************************************************
 *
 */

if (!defined('_PS_VERSION_')) {
    exit;
}


class DesGtm extends Module
{
    
    public function __construct()
    {
        $this->name                   = 'desgtm';
        $this->tab                    = 'analytics_stats';
        $this->version                = '1.0.0';
        $this->author                 = 'David Escudero Sánchez';
        $this->need_instance          = 0;
        $this->ps_versions_compliancy = array(
            'min' => '1.6',
            'max' => _PS_VERSION_
        );
        $this->bootstrap              = true;
        $this->module_key             = 'd0d1284459248ef6cf44c9dbbc0bc954';
        
        parent::__construct();
        
        $this->displayName = $this->l('Google Tag Manager integration');
        $this->description = $this->l('Implements GTM without change any piece of code.');
        
        $this->confirmUninstall = $this->l('Are you sure you want to uninstall?');
        
        if (!Configuration::get('GTM')) {
            $this->warning = $this->l('No name provided');
        }
    }
    
    
    
    public function install()
    {
        if (Shop::isFeatureActive()) {
            Shop::setContext(Shop::CONTEXT_ALL);
        }
        if (!parent::install()
        || !$this->registerHook('header')
        || !$this->registerHook('displayOrderConfirmation')
        || !$this->registerHook('displayFooterProduct')
        || !$this->registerHook('actionValidateOrder')
        || !$this->registerHook('actionOrderStatusUpdate')
        || !Configuration::updateValue('DESGTM', 'ID DE GTM')) {
            return false;
        }
        
        return true;
    }
    
    
    public function uninstall()
    {
        if (!parent::uninstall()
        || !Configuration::deleteByName('DESGTM')
        || !Configuration::deleteByName('DESGTM_TRACK_USUARIOS')) {
            return false;
        }
        
        return true;
    }
    
    
    public function getContent()
    {
        $output = null;
        $js     = '';
        if (Tools::isSubmit('submit' . $this->name)) {
            $ID_GTM             = (string) (Tools::getValue('DESGTM'));
            $TRACK_USUARIOS     = (string) (Tools::getValue('DESGTM_TRACK_USUARIOS'));
            $TRACK_CONVERSIONES = (string) (Tools::getValue('DESGTM_TRACK_CONVERSIONES'));
            $TRACK_PRODUCTOS    = (string) (Tools::getValue('DESGTM_TRACK_PRODUCTOSVISTOS'));
            $TRACK_ANALYTICS    = (string) (Tools::getValue('DESGTM_TRACK_ANALYTICS'));
            if (!$ID_GTM
            || empty($ID_GTM)
            || !Validate::isGenericName($ID_GTM)) {
                $output .= $this->displayError($this->l('Invalid Configuration value'));
            } else {
                Configuration::updateValue('DESGTM', $ID_GTM);
                Configuration::updateValue('DESGTM_TRACK_USUARIOS', $TRACK_USUARIOS);
                Configuration::updateValue('DESGTM_TRACK_CONVERSIONES', $TRACK_CONVERSIONES);
                Configuration::updateValue('DESGTM_TRACK_PRODUCTOSVISTOS', $TRACK_PRODUCTOS);
                Configuration::updateValue('DESGTM_TRACK_ANALYTICS', $TRACK_ANALYTICS);
                $output .= $this->displayConfirmation($this->l('Settings updated'));
            }
        } elseif (Tools::getValue('downloadxml') != '') {
            $typexp = Tools::getValue('downloadxml');
            if (!empty($typexp)) {
                $token = Tools::getAdminTokenLite('AdminModules');
                if ($this->createJSON() == true) {
                    $url = '/modules/desgtm/download.php?token=' . $token;
                    $js  = '<script type="text/javascript">
                    $(document).ready(function() {
                        $.ajax({
                            type: \'GET\',
                            url: "' . $url . '",
                            success: function(data){
                                  if (data == true){
                                    alert(\'This file is not available for download.\');
                                  } else {
                                    window.location ="' . $url . '";
                                  }
                            }
                        })
                    });
                    </script>';
                }
            }
        }
        $this->context->smarty->assign('mytoken', Tools::getAdminTokenLite('AdminModules'));
        $this->context->smarty->assign('myurl', $this->getCurrentUrl());
        $output = $this->context->smarty->fetch($this->local_path . 'views/templates/admin/configuration.tpl');
        return $output . $js . $this->displayForm();
    }
    
    public function displayForm()
    {
        // Get default language
        $default_lang = (int) Configuration::get('PS_LANG_DEFAULT');
        
        // Init Fields form array
        $fields_form            = array();
        $fields_form[0]['form'] = array(
            'legend' => array(
                'title' => $this->l('Configuración del modulo'),
                'class' => 'icon-settings'
            ),
            'input' => array(
                array(
                    'type' => 'text',
                    'label' => $this->l('Etiqueta Google Tag Manager (GTM-AD01JS)'),
                    'desc' => $this->l('Coge el id de Google Tag Manager.'),
                    'name' => 'DESGTM',
                    'size' => 20,
                    'required' => true
                ),
                array(
                    'type' => 'text',
                    'label' => $this->l('ID Google Analytics (UA-1129482-1)'),
                    'desc' => $this->l('Coge el id de Google Analytics.'),
                    'name' => 'DESGTM_TRACK_ANALYTICS',
                    'size' => 20,
                    'required' => true
                ),
                array(
                    'type' => 'switch',
                    'is_bool' => true,
                    'label' => $this->l('Seguimiento de ids de usuarios y emails'),
                    'name' => 'DESGTM_TRACK_USUARIOS',
                    'desc' => $this->l('Realizar seguimiento de emails y usuarios para añadir nuevo campo secundario en Analytics.'),
                    'values' => array(
                        array(
                            'id' => 'active_on',
                            'value' => true,
                            'label' => $this->l('Enabled')
                        ),
                        array(
                            'id' => 'active_off',
                            'value' => false,
                            'label' => $this->l('Disabled')
                        )
                    )
                ),
                array(
                    'type' => 'switch',
                    'is_bool' => true,
                    'label' => $this->l('Seguimiento de conversiones'),
                    'name' => 'DESGTM_TRACK_CONVERSIONES',
                    'desc' => $this->l('Realizar seguimiento de conversiones.'),
                    'values' => array(
                        array(
                            'id' => 'active_on',
                            'value' => true,
                            'label' => $this->l('Enabled')
                        ),
                        array(
                            'id' => 'active_off',
                            'value' => false,
                            'label' => $this->l('Disabled')
                        )
                    )
                ),
                array(
                    'type' => 'switch',
                    'is_bool' => true,
                    'label' => $this->l('Seguimiento de productos vistos'),
                    'name' => 'DESGTM_TRACK_PRODUCTOSVISTOS',
                    'desc' => $this->l('Realizar seguimiento de productos vistos.'),
                    'values' => array(
                        array(
                            'id' => 'active_on',
                            'value' => true,
                            'label' => $this->l('Enabled')
                        ),
                        array(
                            'id' => 'active_off',
                            'value' => false,
                            'label' => $this->l('Disabled')
                        )
                    )
                )
            ),
            'submit' => array(
                'title' => $this->l('Save'),
                'class' => 'btn btn-default pull-right'
            )
        );
        
        $helper = new HelperForm();
        
        // Module, token and currentIndex
        $helper->module          = $this;
        $helper->name_controller = $this->name;
        $helper->token           = Tools::getAdminTokenLite('AdminModules');
        $helper->currentIndex    = AdminController::$currentIndex . '&configure=' . $this->name;
        
        // Language
        $helper->default_form_language    = $default_lang;
        $helper->allow_employee_form_lang = $default_lang;
        
        // Title and toolbar
        $helper->title          = $this->displayName;
        $helper->show_toolbar   = true; // false -> remove toolbar
        $helper->toolbar_scroll = true; // yes - > Toolbar is always visible on the top of the screen.
        $helper->submit_action  = 'submit' . $this->name;
        $helper->toolbar_btn    = array(
            'save' => array(
                'desc' => $this->l('Save'),
                'href' => AdminController::$currentIndex . '&configure=' . $this->name . '&save' . $this->name . '&token=' . Tools::getAdminTokenLite('AdminModules')
            ),
            'back' => array(
                'href' => AdminController::$currentIndex . '&token=' . Tools::getAdminTokenLite('AdminModules'),
                'desc' => $this->l('Back to list')
            )
        );
        
        // Load current value
        $helper->fields_value['DESGTM']                       = Configuration::get('DESGTM');
        $helper->fields_value['DESGTM_TRACK_USUARIOS']        = Configuration::get('DESGTM_TRACK_USUARIOS');
        $helper->fields_value['DESGTM_TRACK_CONVERSIONES']    = Configuration::get('DESGTM_TRACK_CONVERSIONES');
        $helper->fields_value['DESGTM_TRACK_PRODUCTOSVISTOS'] = Configuration::get('DESGTM_TRACK_PRODUCTOSVISTOS');
        $helper->fields_value['DESGTM_TRACK_ANALYTICS']       = Configuration::get('DESGTM_TRACK_ANALYTICS');
        
        return $helper->generateForm($fields_form);
    }
    
    public function hookDisplayHeader()
    {
        $this->context->smarty->assign(array(
            'DES_GTM_ID' => Configuration::get('DESGTM'),
            'DES_TRACK_USUARIOS_EMAIL' => Configuration::get('DESGTM_TRACK_USUARIOS')
        ));
        
        return $this->display(__FILE__, 'desgtm.tpl');
    }
    
    public function hookDisplayFooterProduct($params)
    {
        $this->context->smarty->assign(array(
            'DESGTM_TRACK_PRODUCTOSVISTOS' => Configuration::get('DESGTM_TRACK_PRODUCTOSVISTOS'),
            'product_name' => $params['product']->name,
            'product_price' => $params['product']->price,
            'product_category' => $params['product']->id_category_default,
            'product_id' => $params['product']->id
        ));
        
        return $this->display(__FILE__, 'desgtm_product_view.tpl');
    }
    
    public function hookDisplayOrderConfirmation($params)
    {
        $order     = $params['objOrder'];
        //CONFIGURACIÓN CAPA DE DATOS DE GTM
        $cart      = new Cart($order->id_cart);
        $productos = $cart->getProducts();
        $this->context->smarty->assign(array(
            'id_pedido' => $this->id_order,
            'total_a_pagar' => $order->total_paid_tax_incl,
            'gastos_envio' => $order->total_shipping_tax_excl,
            'impuestos' => ($order->carrier_tax_rate / 100) + 1,
            'productos' => $productos,
            'DESGTM_TRACK_CONVERSIONES' => Configuration::get('DESGTM_TRACK_CONVERSIONES')
        ));
        return $this->display(__FILE__, 'desgtm_order_confirmation.tpl');
    }
    
    public function hookActionValidateOrder($params)
    {
        //$this->conversionRealizada($params, false);
    }
    
    public function hookActionOrderStatusUpdate($params)
    {
        //$this->conversionRealizada($params, true);
    }
    
    public function conversionRealizada($params, $updateOrder)
    {
        if ($updateOrder) {
            if (!empty($params['newOrderStatus']) && Configuration::get('DESGTM_TRACK_CONVERSIONES')) {
                if ($params['newOrderStatus']->id == Configuration::get('PS_OS_WS_PAYMENT')
                || $params['newOrderStatus']->id == Configuration::get('PS_OS_PAYMENT')) {
                    $order     = $params['order'];
                    //CONFIGURACIÓN CAPA DE DATOS DE GTM
                    $cart      = new Cart($order->id_cart);
                    $productos = $cart->getProducts();
                    $this->context->smarty->assign(array(
                        'id_pedido' => $this->id_order,
                        'total_a_pagar' => $order->total_paid_tax_incl,
                        'gastos_envio' => $order->total_shipping_tax_excl,
                        'impuestos' => ($order->carrier_tax_rate / 100) + 1,
                        'productos' => $productos
                    ));
                    return $this->display(__FILE__, 'desgtm_order_confirmation.tpl');
                }
            }
        } else {
            if (!empty($params['orderStatus']) && Configuration::get('DESGTM_TRACK_CONVERSIONES')) {
                if ($params['orderStatus']->id == (int) Configuration::get('PS_OS_WS_PAYMENT')
                || $params['orderStatus']->id == (int) Configuration::get('PS_OS_PAYMENT')
                || $params['orderStatus']->id == 10) {
                    $order     = $params['order'];
                    //CONFIGURACIÓN CAPA DE DATOS DE GTM
                    $cart      = new Cart($order->id_cart);
                    $productos = $cart->getProducts();
                    $this->context->smarty->assign(array(
                        'id_pedido' => $this->id_order,
                        'total_a_pagar' => $order->total_paid_tax_incl,
                        'gastos_envio' => $order->total_shipping_tax_excl,
                        'impuestos' => ($order->carrier_tax_rate / 100) + 1,
                        'productos' => $productos
                    ));
                    return $this->display(__FILE__, 'desgtm_order_confirmation.tpl');
                }
            }
        }
    }
    
    private function getCurrentUrl()
    {
        $url = Tools::strlen($_SERVER['QUERY_STRING']) ? basename($_SERVER['PHP_SELF']) . '?' . $_SERVER['QUERY_STRING'] : basename($_SERVER['PHP_SELF']);
        $pos = strpos($url, 'downloadxml');
        if ($pos === false) {
            return $url;
        } else {
            return Tools::substr($url, 0, $pos - 1);
        }
    }
    
    private function createJSON()
    {
        if (!empty(Configuration::get('DESGTM_TRACK_ANALYTICS'))) {
            $line = $this->xml_settings_gtm . Configuration::get('DESGTM_TRACK_ANALYTICS') . $this->xml_settings_gtm2;
            if ($file = @fopen(dirname(__FILE__) . '/json/configuracion-gtm.json', 'w')) {
                if (!fwrite($file, $line)) {
                    $this->context->controller->errors[] = Tools::displayError($this->l('Error: No hay permisos de escritura en ') . ' ' . dirname(__FILE__) . '/json/configuracion-gtm.json !');
                    fclose($file);
                } else {
                    fclose($file);
                    return true;
                }
            } else {
                $this->context->controller->errors[] = Tools::displayError($this->l('Error de permisos creando el fichero.'));
            }
            return false;
        } else {
            echo '<script type="text/javascript">$(document).ready(function() {alert("' . $this->l('No hemos podido generar el fichero de configuración.') . '\\n\\n' . $this->l('El ID de Analytics no está todavía configurado.') . '") });</script>';
        }
    }
    
    
    public $xml_settings_gtm = '{
    "exportFormatVersion": 2,
    "exportTime": "2017-07-22 07:37:11",
    "containerVersion": {
        "path": "accounts/1628668923/containers/7258588/versions/0",
        "accountId": "1628668923",
        "containerId": "7258588",
        "containerVersionId": "0",
        "container": {
            "path": "accounts/1628668923/containers/7258588",
            "accountId": "1628668923",
            "containerId": "7258588",
            "name": "tests.com",
            "publicId": "GTM-NGFTJBC",
            "usageContext": [
                "WEB"
            ],
            "fingerprint": "1500709011796",
            "tagManagerUrl": "https://tagmanager.google.com/#/container/accounts/1628668923/containers/7258588/workspaces?apiLink=container"
        },
        "tag": [
            {
                "accountId": "1628668923",
                "containerId": "7258588",
                "tagId": "1",
                "name": "Analytics",
                "type": "ua",
                "parameter": [
                    {
                        "type": "BOOLEAN",
                        "key": "overrideGaSettings",
                        "value": "false"
                    },
                    {
                        "type": "TEMPLATE",
                        "key": "trackType",
                        "value": "TRACK_PAGEVIEW"
                    },
                    {
                        "type": "TEMPLATE",
                        "key": "gaSettings",
                        "value": "{{CONFIGURACION ANALYTICS}}"
                    }
                ],
                "fingerprint": "1500708661059",
                "firingTriggerId": [
                    "2147479553"
                ],
                "parentFolderId": "5",
                "tagFiringOption": "ONCE_PER_EVENT"
            },
            {
                "accountId": "1628668923",
                "containerId": "7258588",
                "tagId": "2",
                "name": "Compra realizada",
                "type": "ua",
                "parameter": [
                    {
                        "type": "BOOLEAN",
                        "key": "overrideGaSettings",
                        "value": "false"
                    },
                    {
                        "type": "TEMPLATE",
                        "key": "trackType",
                        "value": "TRACK_TRANSACTION"
                    },
                    {
                        "type": "TEMPLATE",
                        "key": "gaSettings",
                        "value": "{{CONFIGURACION ANALYTICS}}"
                    }
                ],
                "fingerprint": "1500708661060",
                "firingTriggerId": [
                    "8"
                ],
                "parentFolderId": "5",
                "tagFiringOption": "ONCE_PER_EVENT"
            },
            {
                "accountId": "1628668923",
                "containerId": "7258588",
                "tagId": "7",
                "name": "Producto visto",
                "type": "ua",
                "parameter": [
                    {
                        "type": "BOOLEAN",
                        "key": "overrideGaSettings",
                        "value": "false"
                    },
                    {
                        "type": "TEMPLATE",
                        "key": "trackType",
                        "value": "TRACK_PAGEVIEW"
                    },
                    {
                        "type": "TEMPLATE",
                        "key": "gaSettings",
                        "value": "{{CONFIGURACION ANALYTICS}}"
                    }
                ],
                "fingerprint": "1500709005108",
                "firingTriggerId": [
                    "9"
                ],
                "tagFiringOption": "ONCE_PER_EVENT"
            }
        ],
        "trigger": [
            {
                "accountId": "1628668923",
                "containerId": "7258588",
                "triggerId": "8",
                "name": "Compra realizada",
                "type": "CUSTOM_EVENT",
                "customEventFilter": [
                    {
                        "type": "EQUALS",
                        "parameter": [
                            {
                                "type": "TEMPLATE",
                                "key": "arg0",
                                "value": "{{_event}}"
                            },
                            {
                                "type": "TEMPLATE",
                                "key": "arg1",
                                "value": "transactionComplete"
                            }
                        ]
                    }
                ],
                "fingerprint": "1500708957678",
                "parentFolderId": "10"
            },
            {
                "accountId": "1628668923",
                "containerId": "7258588",
                "triggerId": "9",
                "name": "Producto visto",
                "type": "CUSTOM_EVENT",
                "customEventFilter": [
                    {
                        "type": "EQUALS",
                        "parameter": [
                            {
                                "type": "TEMPLATE",
                                "key": "arg0",
                                "value": "{{_event}}"
                            },
                            {
                                "type": "TEMPLATE",
                                "key": "arg1",
                                "value": "productView"
                            }
                        ]
                    }
                ],
                "fingerprint": "1500708964279",
                "parentFolderId": "10"
            }
        ],
        "variable": [
            {
                "accountId": "1628668923",
                "containerId": "7258588",
                "variableId": "3",
                "name": "CONFIGURACION ANALYTICS",
                "type": "gas",
                "parameter": [
                    {
                        "type": "TEMPLATE",
                        "key": "cookieDomain",
                        "value": "auto"
                    },
                    {
                        "type": "BOOLEAN",
                        "key": "useEcommerceDataLayer",
                        "value": "true"
                    },
                    {
                        "type": "BOOLEAN",
                        "key": "doubleClick",
                        "value": "false"
                    },
                    {
                        "type": "BOOLEAN",
                        "key": "setTrackerName",
                        "value": "false"
                    },
                    {
                        "type": "BOOLEAN",
                        "key": "useDebugVersion",
                        "value": "false"
                    },
                    {
                        "type": "BOOLEAN",
                        "key": "useHashAutoLink",
                        "value": "false"
                    },
                    {
                        "type": "BOOLEAN",
                        "key": "decorateFormsAutoLink",
                        "value": "false"
                    },
                    {
                        "type": "BOOLEAN",
                        "key": "enableLinkId",
                        "value": "false"
                    },
                    {
                        "type": "LIST",
                        "key": "dimension",
                        "list": [
                            {
                                "type": "MAP",
                                "map": [
                                    {
                                        "type": "TEMPLATE",
                                        "key": "index",
                                        "value": "0"
                                    },
                                    {
                                        "type": "TEMPLATE",
                                        "key": "dimension",
                                        "value": "{{Email de usuario visitante}}"
                                    }
                                ]
                            }
                        ]
                    },
                    {
                        "type": "BOOLEAN",
                        "key": "enableEcommerce",
                        "value": "true"
                    },
                    {
                        "type": "TEMPLATE",
                        "key": "trackingId",
                        "value": "{{ID ANALYTICS}}"
                    }
                ],
                "fingerprint": "1500708935126",
                "parentFolderId": "5"
            },
            {
                "accountId": "1628668923",
                "containerId": "7258588",
                "variableId": "1",
                "name": "Email de usuario visitante",
                "type": "v",
                "parameter": [
                    {
                        "type": "INTEGER",
                        "key": "dataLayerVersion",
                        "value": "2"
                    },
                    {
                        "type": "BOOLEAN",
                        "key": "setDefaultValue",
                        "value": "false"
                    },
                    {
                        "type": "TEMPLATE",
                        "key": "name",
                        "value": "emailUsuario"
                    }
                ],
                "fingerprint": "1500708661053",
                "parentFolderId": "7"
            },
            {
                "accountId": "1628668923",
                "containerId": "7258588",
                "variableId": "2",
                "name": "ID ANALYTICS",
                "type": "c",
                "parameter": [
                    {
                        "type": "TEMPLATE",
                        "key": "value",
                        "value": "';
    
    public $xml_settings_gtm2 = '"
                    }
                ],
                "fingerprint": "1500708905860",
                "parentFolderId": "5"
            },
            {
                "accountId": "1628668923",
                "containerId": "7258588",
                "variableId": "5",
                "name": "Id del pedido",
                "type": "v",
                "parameter": [
                    {
                        "type": "INTEGER",
                        "key": "dataLayerVersion",
                        "value": "2"
                    },
                    {
                        "type": "BOOLEAN",
                        "key": "setDefaultValue",
                        "value": "false"
                    },
                    {
                        "type": "TEMPLATE",
                        "key": "name",
                        "value": "transactionId"
                    }
                ],
                "fingerprint": "1500708661057",
                "parentFolderId": "7"
            },
            {
                "accountId": "1628668923",
                "containerId": "7258588",
                "variableId": "7",
                "name": "Nombre del producto",
                "type": "v",
                "parameter": [
                    {
                        "type": "INTEGER",
                        "key": "dataLayerVersion",
                        "value": "2"
                    },
                    {
                        "type": "BOOLEAN",
                        "key": "setDefaultValue",
                        "value": "false"
                    },
                    {
                        "type": "TEMPLATE",
                        "key": "name",
                        "value": "productoVisto"
                    }
                ],
                "fingerprint": "1500708925803",
                "parentFolderId": "7"
            },
            {
                "accountId": "1628668923",
                "containerId": "7258588",
                "variableId": "6",
                "name": "Valor total de Compra",
                "type": "v",
                "parameter": [
                    {
                        "type": "INTEGER",
                        "key": "dataLayerVersion",
                        "value": "2"
                    },
                    {
                        "type": "BOOLEAN",
                        "key": "setDefaultValue",
                        "value": "false"
                    },
                    {
                        "type": "TEMPLATE",
                        "key": "name",
                        "value": "transactionTotal"
                    }
                ],
                "fingerprint": "1500708661058",
                "parentFolderId": "7"
            }
        ],
        "folder": [
            {
                "accountId": "1628668923",
                "containerId": "7258588",
                "folderId": "5",
                "name": "ANALYTICS",
                "fingerprint": "1500708661050"
            },
            {
                "accountId": "1628668923",
                "containerId": "7258588",
                "folderId": "10",
                "name": "EVENTOS",
                "fingerprint": "1500708952287"
            },
            {
                "accountId": "1628668923",
                "containerId": "7258588",
                "folderId": "6",
                "name": "FACEBOOK",
                "fingerprint": "1500708661051"
            },
            {
                "accountId": "1628668923",
                "containerId": "7258588",
                "folderId": "7",
                "name": "VARIABLES GLOBALES",
                "fingerprint": "1500708661051"
            }
        ],
        "builtInVariable": [
            {
                "accountId": "1628668923",
                "containerId": "7258588",
                "type": "PAGE_URL",
                "name": "Page URL"
            },
            {
                "accountId": "1628668923",
                "containerId": "7258588",
                "type": "PAGE_HOSTNAME",
                "name": "Page Hostname"
            },
            {
                "accountId": "1628668923",
                "containerId": "7258588",
                "type": "PAGE_PATH",
                "name": "Page Path"
            },
            {
                "accountId": "1628668923",
                "containerId": "7258588",
                "type": "REFERRER",
                "name": "Referrer"
            },
            {
                "accountId": "1628668923",
                "containerId": "7258588",
                "type": "EVENT",
                "name": "Event"
            }
        ],
        "fingerprint": "0",
        "tagManagerUrl": "https://tagmanager.google.com/#/versions/accounts/1628668923/containers/7258588/versions/0?apiLink=version"
    }
	}';
}
